ObjectiveScale

Enum ObjectiveScale 

pub enum ObjectiveScale {
    Sum,
    Mean,
}
Scaling convention for the likelihood part of a compiled objective.

Local and global penalties are not scaled. This keeps penalty weights on a stable scale when switching between summed and mean likelihood objectives.

Variants



Sum

Use the weighted likelihood sum.



Mean

Use the weighted likelihood mean.

For weighted observations the denominator is the sum of observation weights. If all weights are zero, the likelihood contribution is left unscaled at zero.